@@ -47,9 +47,9 @@ class CGSmartImage extends CGExtensions
   function LazyLoadFrontend() { return FALSE; }
   function GetName() { return get_class($this); }
   function GetFriendlyName() { return $this->Lang('friendlyname');  }
-  function GetVersion() { return '1.9'; }
+  function GetVersion() { return '1.9.3'; }
   function MinimumCMSVersion() { return '1.10.3'; }
-  function GetDependencies() { return array('CGExtensions'=>'1.26.4');   }
+  function GetDependencies() { return array('CGExtensions'=>'1.29');   }
   function GetAuthor() { return 'calguy1000'; }
   function GetAuthorEmail() { return 'calguy1000@gmail.com'; }
   function IsPluginModule() { return true; }
@@ -148,7 +148,11 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('filter_watermark','',$this->Lang('param_filter_watermark'));
   }
 
-  function GetHelp() { return $this->Lang('help'); }
+  function GetHelp() 
+  { 
+    return file_get_contents(dirname(__FILE__).'/help.inc');
+  }
+
   function GetAdminDescription()
   {
     return $this->Lang('moddescription');
