@@ -39,6 +39,7 @@ if( !$this->CheckPermission('Modify Site Preferences') ) return;
 
 echo $this->StartTabHeaders();
 echo $this->SetTabHeader('aliases',$this->Lang('aliases'));
+echo $this->SetTabHeader('responsive',$this->Lang('responsive'));
 echo $this->SetTabHeader('embedding',$this->Lang('embedding'));
 //echo $this->SetTabHeader('resizing',$this->Lang('resizing'));
 echo $this->SetTabHeader('general',$this->Lang('general'));
@@ -50,6 +51,10 @@ echo $this->StartTab('aliases',$params);
 include(dirname(__FILE__).'/function.admin_aliases_tab.php');
 echo $this->EndTab();
 
+echo $this->StartTab('responsive',$params);
+include(dirname(__FILE__).'/function.admin_responsive_tab.php');
+echo $this->EndTab();
+
 echo $this->StartTab('embedding',$params);
 include(dirname(__FILE__).'/function.admin_embedding_tab.php');
 echo $this->EndTab();
