@@ -53,22 +53,6 @@ class CGImage_Rotate_Filter extends CGImageFilterBase
    */
   private $_angle = 0;
 
-  /**
-   * The background color of pixels left blank
-   *
-   * @access private
-   * @var integer
-   */
-  private $_bgcolor = 0;
-
-  /**
-   * A flag indicating wether to ignore transparent pixels
-   *
-   * @access private
-   * @var boolean
-   */
-  private $_ignore_tp = 0;
-
   public function __construct(/* variable arguments */)
   {
     $args = func_get_args();
@@ -77,17 +61,12 @@ class CGImage_Rotate_Filter extends CGImageFilterBase
 	$args = $args[0];
       }
 
-    if( count($args) < 2 || count($args) > 3 )
+    if( count($args) != 1 )
       {
 	throw new Exception('Invalid arguments specified for '.get_class($this));
       }
 
     $this->_angle = (int)$args[0] % 360;
-    $this->_bgcolor = (int)$args[1];
-    if( count($args) == 3 )
-      {
-	$this->_ignore_tp = (int)$args[2];
-      }
   }
 
   public function transform(CGImageBase $src)
