@@ -781,12 +781,10 @@ class cgsi_utils
     if( isset($params['max_height']) )
       {
 	$max_height = max(0,(int)$params['max_height']);
-	unset($params['max_height']);
       }
     if( isset($params['max_width']) )
       {
 	$max_width = max(0,(int)$params['max_width']);
-	unset($params['max_width']);
       }
 
     $did_modify = FALSE;
